use crate::relay::ws;
use crate::utils::structs::Context;
use std::net::SocketAddr;
use warp::{Rejection, Reply};

pub async fn ws_handler(
    ws: warp::ws::Ws,
    context: Context,
    real_client_ip: Option<SocketAddr>,
) -> Result<impl Reply, Rejection> {
    Ok(ws.on_upgrade(move |socket| ws::client_connection(socket, context, real_client_ip)))
}

pub async fn relay_config(header: String) -> Result<impl Reply, Rejection> {
    if header != "application/nostr+json" {
        Err(warp::reject::not_found())
    } else {
        let res = serde_json::json!({
            "contact": "klink@zhitno.st",
            "name": "zhitno.st",
            "description": "Very *special* nostr relay",
            "supported_nips": [ 1, 9, 11, 12, 15, 16, 20, 22, 28, 33 ],
            "software": "git+https://git.zhitno.st/Klink/sneedstr.git",
            "version": "0.1.0"
        });
        Ok(warp::reply::json(&res))
    }
}
